@@ -10,9 +10,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2012 Magic3 Project.
+ * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: fileuploader.php 5062 2012-07-24 05:18:58Z fishbone $
+ * @version    SVN: $Id: fileuploader.php 6172 2013-07-16 02:22:39Z fishbone $
  * @link       http://www.magic3.org
  */
 /**
@@ -76,14 +76,24 @@ class qqUploadedFileForm {
 
 class qqFileUploader {
     private $allowedExtensions = array();
-    private $sizeLimit = 10485760;
+    private $sizeLimit = 10485760;			// アップロード可能なファイルの最大サイズ
     private $file;
 
-    function __construct(array $allowedExtensions = array(), $sizeLimit = 10485760){
+    function __construct(array $allowedExtensions = array(), $sizeLimit = null)
+	{
+		global $gSystemManager;
+		
         $allowedExtensions = array_map("strtolower", $allowedExtensions);
-            
-        $this->allowedExtensions = $allowedExtensions;        
-        $this->sizeLimit = $sizeLimit;
+        $this->allowedExtensions = $allowedExtensions;
+		
+		// アップロードファイルの最大サイズはPHPの設定に合わせる
+        //$this->sizeLimit = $sizeLimit;
+		$maxFileSize = $gSystemManager->getMaxFileSizeForUpload(true);
+		if (empty($sizeLimit) || $sizeLimit > $maxFileSize){
+			$this->sizeLimit = $maxFileSize;
+		} else {
+			$this->sizeLimit = $sizeLimit;
+		}
 
         //$this->checkServerSettings();       // サーバ環境チェックなし
         if (isset($_GET['qqfile'])) {
@@ -95,17 +105,17 @@ class qqFileUploader {
         }
     }
     
-    private function checkServerSettings(){        
+/*    private function checkServerSettings(){
         $postSize = $this->toBytes(ini_get('post_max_size'));
-        $uploadSize = $this->toBytes(ini_get('upload_max_filesize'));        
+        $uploadSize = $this->toBytes(ini_get('upload_max_filesize'));
         
         if ($postSize < $this->sizeLimit || $uploadSize < $this->sizeLimit){
             $size = max(1, $this->sizeLimit / 1024 / 1024) . 'M';
             die("{'error':'increase post_max_size and upload_max_filesize to $size'}");    
         }        
-    }
+    }*/
     
-    private function toBytes($str){
+/*    private function toBytes($str){
         $val = trim($str);
         $last = strtolower($str[strlen($str)-1]);
         switch($last) {
@@ -114,12 +124,15 @@ class qqFileUploader {
             case 'k': $val *= 1024;        
         }
         return $val;
-    }
+    }*/
     
     /**
      * Returns array('success'=>true) or array('error'=>'error message')
      */
-    function handleUpload($uploadDirectory){
+    function handleUpload($uploadDirectory)
+	{
+		global $gSystemManager;
+		
 		$uploadDirectory = rtrim($uploadDirectory, '/\\');
 		
         if (!is_writable($uploadDirectory)){
@@ -132,15 +145,24 @@ class qqFileUploader {
         
         $size = $this->file->getSize();
         
-        if ($size == 0) {
-            return array('error' => 'File is empty');
+        if ($size == 0){
+			// IE8では、アップロードファイルのサイズが「upload_max_filesize」よりも大きいと0が返る
+			if (isset($_SERVER["CONTENT_LENGTH"])){
+				//$displayMaxSize = ini_get('upload_max_filesize');
+				//$errorMsg = 'File size is too large. ' . $_SERVER['CONTENT_LENGTH'] . ' bytes exceeds upload_max_filesize(' . $displayMaxSize . ' bytes).';
+				$displayMaxSize = $gSystemManager->getMaxFileSizeForUpload();
+				$errorMsg = 'File size is too large. ' . $_SERVER['CONTENT_LENGTH'] . ' bytes exceeds max upload filesize(' . $displayMaxSize . ' bytes).';
+			} else {
+				$errorMsg = 'File is empty';
+			}
+			return array('error' => $errorMsg);
         }
         
         if ($size > $this->sizeLimit) {
             return array('error' => 'File is too large');
         }
         
-		$filename = strtr($this->file->getName(), ' ', '_');
+		$filename = strtr($this->file->getName(), ' ', '_');	// 半角スペースをアンダーバーに変換(Firefox対応)
         $pathinfo = pathinfo($filename);
 //        $filename = $pathinfo['filename'];
         $ext = $pathinfo['extension'];
